/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DCore.h"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 45 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 39 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQBackendNode.cpp"

#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 43 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQBackendNode.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 72 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQBackendNode.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 75 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQBackendNode.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 78 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQBackendNode.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 81 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQBackendNode.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 53 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 134 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQBackendNode.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 169 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCoreQt3DCoreQBackendNode.cpp"


class sipQt3DCore_QBackendNode : public ::Qt3DCore::QBackendNode
{
public:
    sipQt3DCore_QBackendNode(::Qt3DCore::QBackendNode::Mode);
    virtual ~sipQt3DCore_QBackendNode();

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void sceneChangeEvent(const ::Qt3DCore::QSceneChangePtr&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQt3DCore_QBackendNode(const sipQt3DCore_QBackendNode &);
    sipQt3DCore_QBackendNode &operator = (const sipQt3DCore_QBackendNode &);

    char sipPyMethods[1];
};

sipQt3DCore_QBackendNode::sipQt3DCore_QBackendNode(::Qt3DCore::QBackendNode::Mode a0): ::Qt3DCore::QBackendNode(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQt3DCore_QBackendNode::~sipQt3DCore_QBackendNode()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

void sipQt3DCore_QBackendNode::sceneChangeEvent(const ::Qt3DCore::QSceneChangePtr& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_sceneChangeEvent);

    if (!sipMeth)
    {
        ::Qt3DCore::QBackendNode::sceneChangeEvent(a0);
        return;
    }

    extern void sipVH_Qt3DCore_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::Qt3DCore::QSceneChangePtr&);

    sipVH_Qt3DCore_6(sipGILState, sipImportedVirtErrorHandlers_Qt3DCore_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_Qt3DCore_QBackendNode_peerId, "peerId(self) -> QNodeId");

extern "C" {static PyObject *meth_Qt3DCore_QBackendNode_peerId(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QBackendNode_peerId(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DCore::QBackendNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DCore_QBackendNode, &sipCpp))
        {
            ::Qt3DCore::QNodeId*sipRes;

            sipRes = new ::Qt3DCore::QNodeId(sipCpp->peerId());

            return sipConvertFromNewType(sipRes, sipType_Qt3DCore_QNodeId, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBackendNode, sipName_peerId, doc_Qt3DCore_QBackendNode_peerId);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QBackendNode_setEnabled, "setEnabled(self, enabled: bool)");

extern "C" {static PyObject *meth_Qt3DCore_QBackendNode_setEnabled(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QBackendNode_setEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::Qt3DCore::QBackendNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_Qt3DCore_QBackendNode, &sipCpp, &a0))
        {
            sipCpp->setEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBackendNode, sipName_setEnabled, doc_Qt3DCore_QBackendNode_setEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QBackendNode_isEnabled, "isEnabled(self) -> bool");

extern "C" {static PyObject *meth_Qt3DCore_QBackendNode_isEnabled(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QBackendNode_isEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DCore::QBackendNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DCore_QBackendNode, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBackendNode, sipName_isEnabled, doc_Qt3DCore_QBackendNode_isEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QBackendNode_mode, "mode(self) -> QBackendNode.Mode");

extern "C" {static PyObject *meth_Qt3DCore_QBackendNode_mode(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QBackendNode_mode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DCore::QBackendNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_Qt3DCore_QBackendNode, &sipCpp))
        {
            ::Qt3DCore::QBackendNode::Mode sipRes;

            sipRes = sipCpp->mode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt3DCore_QBackendNode_Mode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBackendNode, sipName_mode, doc_Qt3DCore_QBackendNode_mode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QBackendNode_notifyObservers, "notifyObservers(self, e: QSceneChange)");

extern "C" {static PyObject *meth_Qt3DCore_QBackendNode_notifyObservers(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QBackendNode_notifyObservers(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DCore::QSceneChangePtr* a0;
        int a0State = 0;
        ::Qt3DCore::QBackendNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1", &sipSelf, sipType_Qt3DCore_QBackendNode, &sipCpp, sipType_QSharedPointer_0100Qt3DCore_QSceneChange, &a0, &a0State))
        {
            sipCpp->notifyObservers(*a0);
            sipReleaseType(const_cast< ::Qt3DCore::QSceneChangePtr *>(a0), sipType_QSharedPointer_0100Qt3DCore_QSceneChange, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBackendNode, sipName_notifyObservers, doc_Qt3DCore_QBackendNode_notifyObservers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QBackendNode_sceneChangeEvent, "sceneChangeEvent(self, e: QSceneChange)");

extern "C" {static PyObject *meth_Qt3DCore_QBackendNode_sceneChangeEvent(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QBackendNode_sceneChangeEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::Qt3DCore::QSceneChangePtr* a0;
        int a0State = 0;
        ::Qt3DCore::QBackendNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1", &sipSelf, sipType_Qt3DCore_QBackendNode, &sipCpp, sipType_QSharedPointer_0100Qt3DCore_QSceneChange, &a0, &a0State))
        {
            (sipSelfWasArg ? sipCpp->::Qt3DCore::QBackendNode::sceneChangeEvent(*a0) : sipCpp->sceneChangeEvent(*a0));
            sipReleaseType(const_cast< ::Qt3DCore::QSceneChangePtr *>(a0), sipType_QSharedPointer_0100Qt3DCore_QSceneChange, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBackendNode, sipName_sceneChangeEvent, doc_Qt3DCore_QBackendNode_sceneChangeEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QBackendNode_sendCommand, "sendCommand(self, name: str|None, data: Any, replyTo: int = Qt3DCore.QNodeCommand.CommandId()) -> int");

extern "C" {static PyObject *meth_Qt3DCore_QBackendNode_sendCommand(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QBackendNode_sendCommand(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QVariant* a1;
        int a1State = 0;
        ::Qt3DCore::QNodeCommand::CommandId a2 = Qt3DCore::QNodeCommand::CommandId();
        ::Qt3DCore::QBackendNode *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_replyTo,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "pJ1J1|o", &sipSelf, sipType_Qt3DCore_QBackendNode, &sipCpp, sipType_QString, &a0, &a0State, sipType_QVariant, &a1, &a1State, &a2))
        {
            ::Qt3DCore::QNodeCommand::CommandId sipRes;

            sipRes = sipCpp->sendCommand(*a0, *a1, a2);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QVariant *>(a1), sipType_QVariant, a1State);

            return PyLong_FromUnsignedLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBackendNode, sipName_sendCommand, doc_Qt3DCore_QBackendNode_sendCommand);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_Qt3DCore_QBackendNode_sendReply, "sendReply(self, command: QNodeCommand)");

extern "C" {static PyObject *meth_Qt3DCore_QBackendNode_sendReply(PyObject *, PyObject *);}
static PyObject *meth_Qt3DCore_QBackendNode_sendReply(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::Qt3DCore::QNodeCommandPtr* a0;
        int a0State = 0;
        ::Qt3DCore::QBackendNode *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1", &sipSelf, sipType_Qt3DCore_QBackendNode, &sipCpp, sipType_QSharedPointer_0100Qt3DCore_QNodeCommand, &a0, &a0State))
        {
            sipCpp->sendReply(*a0);
            sipReleaseType(const_cast< ::Qt3DCore::QNodeCommandPtr *>(a0), sipType_QSharedPointer_0100Qt3DCore_QNodeCommand, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBackendNode, sipName_sendReply, doc_Qt3DCore_QBackendNode_sendReply);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_Qt3DCore_QBackendNode(void *, int);}
static void release_Qt3DCore_QBackendNode(void *sipCppV, int sipState)
{
    if (sipState & SIP_DERIVED_CLASS)
        delete reinterpret_cast<sipQt3DCore_QBackendNode *>(sipCppV);
    else
        delete reinterpret_cast< ::Qt3DCore::QBackendNode *>(sipCppV);
}


extern "C" {static void *array_Qt3DCore_QBackendNode(Py_ssize_t);}
static void *array_Qt3DCore_QBackendNode(Py_ssize_t sipNrElem)
{
    return new ::Qt3DCore::QBackendNode[sipNrElem];
}


extern "C" {static void array_delete_Qt3DCore_QBackendNode(void *);}
static void array_delete_Qt3DCore_QBackendNode(void *sipCpp)
{
    delete[] reinterpret_cast< ::Qt3DCore::QBackendNode *>(sipCpp);
}


extern "C" {static void dealloc_Qt3DCore_QBackendNode(sipSimpleWrapper *);}
static void dealloc_Qt3DCore_QBackendNode(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQt3DCore_QBackendNode *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_Qt3DCore_QBackendNode(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_Qt3DCore_QBackendNode(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_Qt3DCore_QBackendNode(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQt3DCore_QBackendNode *sipCpp = SIP_NULLPTR;

    {
        ::Qt3DCore::QBackendNode::Mode a0 = Qt3DCore::QBackendNode::ReadOnly;

        static const char *sipKwdList[] = {
            sipName_mode,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|E", sipType_Qt3DCore_QBackendNode_Mode, &a0))
        {
            sipCpp = new sipQt3DCore_QBackendNode(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_Qt3DCore_QBackendNode[] = {
    {sipName_isEnabled, meth_Qt3DCore_QBackendNode_isEnabled, METH_VARARGS, doc_Qt3DCore_QBackendNode_isEnabled},
    {sipName_mode, meth_Qt3DCore_QBackendNode_mode, METH_VARARGS, doc_Qt3DCore_QBackendNode_mode},
    {sipName_notifyObservers, meth_Qt3DCore_QBackendNode_notifyObservers, METH_VARARGS, doc_Qt3DCore_QBackendNode_notifyObservers},
    {sipName_peerId, meth_Qt3DCore_QBackendNode_peerId, METH_VARARGS, doc_Qt3DCore_QBackendNode_peerId},
    {sipName_sceneChangeEvent, meth_Qt3DCore_QBackendNode_sceneChangeEvent, METH_VARARGS, doc_Qt3DCore_QBackendNode_sceneChangeEvent},
    {sipName_sendCommand, SIP_MLMETH_CAST(meth_Qt3DCore_QBackendNode_sendCommand), METH_VARARGS|METH_KEYWORDS, doc_Qt3DCore_QBackendNode_sendCommand},
    {sipName_sendReply, meth_Qt3DCore_QBackendNode_sendReply, METH_VARARGS, doc_Qt3DCore_QBackendNode_sendReply},
    {sipName_setEnabled, meth_Qt3DCore_QBackendNode_setEnabled, METH_VARARGS, doc_Qt3DCore_QBackendNode_setEnabled}
};

static sipEnumMemberDef enummembers_Qt3DCore_QBackendNode[] = {
    {sipName_ReadOnly, static_cast<int>(::Qt3DCore::QBackendNode::ReadOnly), 20},
    {sipName_ReadWrite, static_cast<int>(::Qt3DCore::QBackendNode::ReadWrite), 20},
};

PyDoc_STRVAR(doc_Qt3DCore_QBackendNode, "\1QBackendNode(mode: QBackendNode.Mode = Qt3DCore.QBackendNode.ReadOnly)");


static pyqt5ClassPluginDef plugin_Qt3DCore_QBackendNode = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_Qt3DCore_Qt3DCore_QBackendNode = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_Qt3DCore__QBackendNode,
        SIP_NULLPTR,
        &plugin_Qt3DCore_QBackendNode,
    },
    {
        sipNameNr_QBackendNode,
        {0, 0, 1},
        8, methods_Qt3DCore_QBackendNode,
        2, enummembers_Qt3DCore_QBackendNode,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_Qt3DCore_QBackendNode,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_Qt3DCore_QBackendNode,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_Qt3DCore_QBackendNode,
    SIP_NULLPTR,
    array_Qt3DCore_QBackendNode,
    SIP_NULLPTR,
    release_Qt3DCore_QBackendNode,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_Qt3DCore_QBackendNode,
    sizeof (::Qt3DCore::QBackendNode),
};
